==> jc-1.4.0.tar.gz: java/beans/beancontext/BeanContextServiceRevokedEvent.h <==
// public class java.beans.beancontext.BeanContextServiceRevokedEvent

// class file dependencies
// @dep_class 83892d580401761a java_beans_beancontext_BeanContextEvent
// @dep_class bf8a3bf2c762366c java_beans_beancontext_BeanContextServiceRevokedEvent
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class e4988e4c1a7050ab java_util_EventObject

// header file dependencies
// @dep_header java_beans_beancontext_BeanContextEvent

#include "java/beans/beancontext/BeanContextEvent.h"

#ifndef _JC_java_beans_beancontext_BeanContextServiceRevokedEvent_H_
#define _JC_java_beans_beancontext_BeanContextServiceRevokedEvent_H_

// Forward structure declarations
struct _jc_java_beans_beancontext_BeanContextServices$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_beans_beancontext_BeanContextServiceRevokedEvent$sub_refs	_jc_java_beans_beancontext_BeanContextServiceRevokedEvent$sub_refs;
typedef struct _jc_java_beans_beancontext_BeanContextServiceRevokedEvent$sub_nonrefs	_jc_java_beans_beancontext_BeanContextServiceRevokedEvent$sub_nonrefs;
typedef struct _jc_java_beans_beancontext_BeanContextServiceRevokedEvent$refs	_jc_java_beans_beancontext_BeanContextServiceRevokedEvent$refs;
typedef struct _jc_java_beans_beancontext_BeanContextServiceRevokedEvent$nonrefs	_jc_java_beans_beancontext_BeanContextServiceRevokedEvent$nonrefs;
typedef struct _jc_java_beans_beancontext_BeanContextServiceRevokedEvent$object	_jc_java_beans_beancontext_BeanContextServiceRevokedEvent$object;

typedef const struct _jc_java_beans_beancontext_BeanContextServiceRevokedEvent$vmethods	_jc_java_beans_beancontext_BeanContextServiceRevokedEvent$vmethods;
typedef const struct _jc_java_beans_beancontext_BeanContextServiceRevokedEvent$vtable	_jc_java_beans_beancontext_BeanContextServiceRevokedEvent$vtable;
typedef const struct _jc_java_beans_beancontext_BeanContextServiceRevokedEvent$vtype	_jc_java_beans_beancontext_BeanContextServiceRevokedEvent$vtype;

// Constructors
extern void _jc_java_beans_beancontext_BeanContextServiceRevokedEvent$method$_init$ece5d1767b3e66a7(_jc_env *, struct _jc_java_beans_beancontext_BeanContextServiceRevokedEvent$object *, struct _jc_object *, struct _jc_java_lang_Class$object *, jboolean);

// Virtual methods
extern struct _jc_java_lang_Class$object *_jc_java_beans_beancontext_BeanContextServiceRevokedEvent$method$getServiceClass$db02eb3ca356db13(_jc_env *, struct _jc_java_beans_beancontext_BeanContextServiceRevokedEvent$object *);
extern struct _jc_object *_jc_java_beans_beancontext_BeanContextServiceRevokedEvent$method$getSourceAsBeanContextServices$ab85327a997ff09b(_jc_env *, struct _jc_java_beans_beancontext_BeanContextServiceRevokedEvent$object *);
extern jboolean _jc_java_beans_beancontext_BeanContextServiceRevokedEvent$method$isCurrentServiceInvalidNow$20b3b555eb71154f(_jc_env *, struct _jc_java_beans_beancontext_BeanContextServiceRevokedEvent$object *);
extern jboolean _jc_java_beans_beancontext_BeanContextServiceRevokedEvent$method$isServiceClass$ed80013e209ff890(_jc_env *, struct _jc_java_beans_beancontext_BeanContextServiceRevokedEvent$object *, struct _jc_java_lang_Class$object *);

// Virtual method descriptors
extern _jc_method _jc_java_beans_beancontext_BeanContextServiceRevokedEvent$method_info$getServiceClass$db02eb3ca356db13;
extern _jc_method _jc_java_beans_beancontext_BeanContextServiceRevokedEvent$method_info$getSourceAsBeanContextServices$ab85327a997ff09b;
extern _jc_method _jc_java_beans_beancontext_BeanContextServiceRevokedEvent$method_info$isCurrentServiceInvalidNow$20b3b555eb71154f;
extern _jc_method _jc_java_beans_beancontext_BeanContextServiceRevokedEvent$method_info$isServiceClass$ed80013e209ff890;

// Virtual methods structure
struct _jc_java_beans_beancontext_BeanContextServiceRevokedEvent$vmethods {
	struct _jc_java_lang_Class$object	*(*getServiceClass$db02eb3ca356db13)(_jc_env *, struct _jc_java_beans_beancontext_BeanContextServiceRevokedEvent$object *);
	struct _jc_object	*(*getSourceAsBeanContextServices$ab85327a997ff09b)(_jc_env *, struct _jc_java_beans_beancontext_BeanContextServiceRevokedEvent$object *);
	jboolean	(*isCurrentServiceInvalidNow$20b3b555eb71154f)(_jc_env *, struct _jc_java_beans_beancontext_BeanContextServiceRevokedEvent$object *);
	jboolean	(*isServiceClass$ed80013e209ff890)(_jc_env *, struct _jc_java_beans_beancontext_BeanContextServiceRevokedEvent$object *, struct _jc_java_lang_Class$object *);
};

// Vtable
struct _jc_java_beans_beancontext_BeanContextServiceRevokedEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventObject$vmethods	java_util_EventObject;
	_jc_java_beans_beancontext_BeanContextEvent$vmethods	java_beans_beancontext_BeanContextEvent;
	_jc_java_beans_beancontext_BeanContextServiceRevokedEvent$vmethods	java_beans_beancontext_BeanContextServiceRevokedEvent;
};

// Vtype
struct _jc_java_beans_beancontext_BeanContextServiceRevokedEvent$vtype {
	_jc_type			type;
	_jc_java_beans_beancontext_BeanContextServiceRevokedEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_beans_beancontext_BeanContextServiceRevokedEvent$sub_refs {
	struct _jc_java_lang_Class$object	*serviceClass;
};

// Reference instance fields (object)
struct _jc_java_beans_beancontext_BeanContextServiceRevokedEvent$refs {
    _jc_java_beans_beancontext_BeanContextServiceRevokedEvent$sub_refs	java_beans_beancontext_BeanContextServiceRevokedEvent;
    _jc_java_beans_beancontext_BeanContextEvent$sub_refs	java_beans_beancontext_BeanContextEvent;
    _jc_java_util_EventObject$sub_refs	java_util_EventObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_beans_beancontext_BeanContextServiceRevokedEvent$sub_nonrefs {
	jboolean	invalidateRefs;
};

// Non-reference instance fields (object)
struct _jc_java_beans_beancontext_BeanContextServiceRevokedEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventObject$sub_nonrefs	java_util_EventObject;
    _jc_java_beans_beancontext_BeanContextEvent$sub_nonrefs	java_beans_beancontext_BeanContextEvent;
    _jc_java_beans_beancontext_BeanContextServiceRevokedEvent$sub_nonrefs	java_beans_beancontext_BeanContextServiceRevokedEvent;
};

// Object instance structure
struct _jc_java_beans_beancontext_BeanContextServiceRevokedEvent$object {
	_jc_java_beans_beancontext_BeanContextServiceRevokedEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_java_beans_beancontext_BeanContextServiceRevokedEvent$vtype	*vtype;
	_jc_java_beans_beancontext_BeanContextServiceRevokedEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_beans_beancontext_BeanContextServiceRevokedEvent$vtype _jc_java_beans_beancontext_BeanContextServiceRevokedEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_beans_beancontext_BeanContextServiceRevokedEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_beans_beancontext_BeanContextServiceRevokedEvent$class_object;

#endif	/* _JC_java_beans_beancontext_BeanContextServiceRevokedEvent_H_ */

==> jc-1.4.6.tar.gz: java/beans/beancontext/BeanContextServiceRevokedEvent.h <==
// public class java.beans.beancontext.BeanContextServiceRevokedEvent

// class file dependencies
// @dep_class 83892d580401761a java_beans_beancontext_BeanContextEvent
// @dep_class bf8a3bf2c762366c java_beans_beancontext_BeanContextServiceRevokedEvent
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class e4988e4c1a7050ab java_util_EventObject

// header file dependencies
// @dep_header java_beans_beancontext_BeanContextEvent

#include "java/beans/beancontext/BeanContextEvent.h"

#ifndef _JC_java_beans_beancontext_BeanContextServiceRevokedEvent_H_
#define _JC_java_beans_beancontext_BeanContextServiceRevokedEvent_H_

// Forward structure declarations
struct _jc_java_beans_beancontext_BeanContextServices$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_beans_beancontext_BeanContextServiceRevokedEvent$sub_refs	_jc_java_beans_beancontext_BeanContextServiceRevokedEvent$sub_refs;
typedef struct _jc_java_beans_beancontext_BeanContextServiceRevokedEvent$sub_nonrefs	_jc_java_beans_beancontext_BeanContextServiceRevokedEvent$sub_nonrefs;
typedef struct _jc_java_beans_beancontext_BeanContextServiceRevokedEvent$refs	_jc_java_beans_beancontext_BeanContextServiceRevokedEvent$refs;
typedef struct _jc_java_beans_beancontext_BeanContextServiceRevokedEvent$nonrefs	_jc_java_beans_beancontext_BeanContextServiceRevokedEvent$nonrefs;
typedef struct _jc_java_beans_beancontext_BeanContextServiceRevokedEvent$object	_jc_java_beans_beancontext_BeanContextServiceRevokedEvent$object;

typedef const struct _jc_java_beans_beancontext_BeanContextServiceRevokedEvent$vmethods	_jc_java_beans_beancontext_BeanContextServiceRevokedEvent$vmethods;
typedef const struct _jc_java_beans_beancontext_BeanContextServiceRevokedEvent$vtable	_jc_java_beans_beancontext_BeanContextServiceRevokedEvent$vtable;
typedef const struct _jc_java_beans_beancontext_BeanContextServiceRevokedEvent$vtype	_jc_java_beans_beancontext_BeanContextServiceRevokedEvent$vtype;

// Constructors
extern void _jc_java_beans_beancontext_BeanContextServiceRevokedEvent$method$_init$ece5d1767b3e66a7(_jc_env *, struct _jc_java_beans_beancontext_BeanContextServiceRevokedEvent$object *, struct _jc_object *, struct _jc_java_lang_Class$object *, jboolean) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Class$object *_jc_java_beans_beancontext_BeanContextServiceRevokedEvent$method$getServiceClass$db02eb3ca356db13(_jc_env *, struct _jc_java_beans_beancontext_BeanContextServiceRevokedEvent$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_java_beans_beancontext_BeanContextServiceRevokedEvent$method$getSourceAsBeanContextServices$ab85327a997ff09b(_jc_env *, struct _jc_java_beans_beancontext_BeanContextServiceRevokedEvent$object *) _JC_JCNI_ATTR;
extern jboolean _jc_java_beans_beancontext_BeanContextServiceRevokedEvent$method$isCurrentServiceInvalidNow$20b3b555eb71154f(_jc_env *, struct _jc_java_beans_beancontext_BeanContextServiceRevokedEvent$object *) _JC_JCNI_ATTR;
extern jboolean _jc_java_beans_beancontext_BeanContextServiceRevokedEvent$method$isServiceClass$ed80013e209ff890(_jc_env *, struct _jc_java_beans_beancontext_BeanContextServiceRevokedEvent$object *, struct _jc_java_lang_Class$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_beans_beancontext_BeanContextServiceRevokedEvent$method_info$getServiceClass$db02eb3ca356db13;
extern _jc_method _jc_java_beans_beancontext_BeanContextServiceRevokedEvent$method_info$getSourceAsBeanContextServices$ab85327a997ff09b;
extern _jc_method _jc_java_beans_beancontext_BeanContextServiceRevokedEvent$method_info$isCurrentServiceInvalidNow$20b3b555eb71154f;
extern _jc_method _jc_java_beans_beancontext_BeanContextServiceRevokedEvent$method_info$isServiceClass$ed80013e209ff890;

// Virtual methods structure
struct _jc_java_beans_beancontext_BeanContextServiceRevokedEvent$vmethods {
	struct _jc_java_lang_Class$object	*(*getServiceClass$db02eb3ca356db13)(_jc_env *, struct _jc_java_beans_beancontext_BeanContextServiceRevokedEvent$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getSourceAsBeanContextServices$ab85327a997ff09b)(_jc_env *, struct _jc_java_beans_beancontext_BeanContextServiceRevokedEvent$object *) _JC_JCNI_ATTR;
	jboolean	(*isCurrentServiceInvalidNow$20b3b555eb71154f)(_jc_env *, struct _jc_java_beans_beancontext_BeanContextServiceRevokedEvent$object *) _JC_JCNI_ATTR;
	jboolean	(*isServiceClass$ed80013e209ff890)(_jc_env *, struct _jc_java_beans_beancontext_BeanContextServiceRevokedEvent$object *, struct _jc_java_lang_Class$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_beans_beancontext_BeanContextServiceRevokedEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventObject$vmethods	java_util_EventObject;
	_jc_java_beans_beancontext_BeanContextEvent$vmethods	java_beans_beancontext_BeanContextEvent;
	_jc_java_beans_beancontext_BeanContextServiceRevokedEvent$vmethods	java_beans_beancontext_BeanContextServiceRevokedEvent;
};

// Vtype
struct _jc_java_beans_beancontext_BeanContextServiceRevokedEvent$vtype {
	_jc_type			type;
	_jc_java_beans_beancontext_BeanContextServiceRevokedEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_beans_beancontext_BeanContextServiceRevokedEvent$sub_refs {
	struct _jc_java_lang_Class$object	*serviceClass;
};

// Reference instance fields (object)
struct _jc_java_beans_beancontext_BeanContextServiceRevokedEvent$refs {
    _jc_java_beans_beancontext_BeanContextServiceRevokedEvent$sub_refs	java_beans_beancontext_BeanContextServiceRevokedEvent;
    _jc_java_beans_beancontext_BeanContextEvent$sub_refs	java_beans_beancontext_BeanContextEvent;
    _jc_java_util_EventObject$sub_refs	java_util_EventObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_beans_beancontext_BeanContextServiceRevokedEvent$sub_nonrefs {
	jboolean	invalidateRefs;
};

// Non-reference instance fields (object)
struct _jc_java_beans_beancontext_BeanContextServiceRevokedEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventObject$sub_nonrefs	java_util_EventObject;
    _jc_java_beans_beancontext_BeanContextEvent$sub_nonrefs	java_beans_beancontext_BeanContextEvent;
    _jc_java_beans_beancontext_BeanContextServiceRevokedEvent$sub_nonrefs	java_beans_beancontext_BeanContextServiceRevokedEvent;
};

// Object instance structure
struct _jc_java_beans_beancontext_BeanContextServiceRevokedEvent$object {
	_jc_java_beans_beancontext_BeanContextServiceRevokedEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_java_beans_beancontext_BeanContextServiceRevokedEvent$vtype	*vtype;
	_jc_java_beans_beancontext_BeanContextServiceRevokedEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_beans_beancontext_BeanContextServiceRevokedEvent$vtype _jc_java_beans_beancontext_BeanContextServiceRevokedEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_beans_beancontext_BeanContextServiceRevokedEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_beans_beancontext_BeanContextServiceRevokedEvent$class_object;

#endif	/* _JC_java_beans_beancontext_BeanContextServiceRevokedEvent_H_ */
